@@ -5,7 +5,7 @@ import logging
 import time
 from collections import deque
 from email.utils import formatdate
-from typing import Callable, Deque, Dict, List, Optional, Union, cast
+from typing import Callable, Deque, Optional, Union, cast
 
 import aioquic
 import wsproto
@@ -44,7 +44,7 @@ class HttpRequestHandler:
         authority: bytes,
         connection: HttpConnection,
         protocol: QuicConnectionProtocol,
-        scope: Dict,
+        scope: dict,
         stream_ended: bool,
         stream_id: int,
         transmit: Callable[[], None],
@@ -52,7 +52,7 @@ class HttpRequestHandler:
         self.authority = authority
         self.connection = connection
         self.protocol = protocol
-        self.queue: asyncio.Queue[Dict] = asyncio.Queue()
+        self.queue: asyncio.Queue[dict] = asyncio.Queue()
         self.scope = scope
         self.stream_id = stream_id
         self.transmit = transmit
@@ -77,10 +77,10 @@ class HttpRequestHandler:
     async def run_asgi(self, app: AsgiApplication) -> None:
         await app(self.scope, self.receive, self.send)
 
-    async def receive(self) -> Dict:
+    async def receive(self) -> dict:
         return await self.queue.get()
 
-    async def send(self, message: Dict) -> None:
+    async def send(self, message: dict) -> None:
         if message["type"] == "http.response.start":
             self.connection.send_headers(
                 stream_id=self.stream_id,
@@ -129,14 +129,14 @@ class WebSocketHandler:
         self,
         *,
         connection: HttpConnection,
-        scope: Dict,
+        scope: dict,
         stream_id: int,
         transmit: Callable[[], None],
     ) -> None:
         self.closed = False
         self.connection = connection
         self.http_event_queue: Deque[DataReceived] = deque()
-        self.queue: asyncio.Queue[Dict] = asyncio.Queue()
+        self.queue: asyncio.Queue[dict] = asyncio.Queue()
         self.scope = scope
         self.stream_id = stream_id
         self.transmit = transmit
@@ -171,10 +171,10 @@ class WebSocketHandler:
             if not self.closed:
                 await self.send({"type": "websocket.close", "code": 1000})
 
-    async def receive(self) -> Dict:
+    async def receive(self) -> dict:
         return await self.queue.get()
 
-    async def send(self, message: Dict) -> None:
+    async def send(self, message: dict) -> None:
         data = b""
         end_stream = False
         if message["type"] == "websocket.accept":
@@ -229,7 +229,7 @@ class WebTransportHandler:
         self,
         *,
         connection: H3Connection,
-        scope: Dict,
+        scope: dict,
         stream_id: int,
         transmit: Callable[[], None],
     ) -> None:
@@ -237,7 +237,7 @@ class WebTransportHandler:
         self.closed = False
         self.connection = connection
         self.http_event_queue: Deque[H3Event] = deque()
-        self.queue: asyncio.Queue[Dict] = asyncio.Queue()
+        self.queue: asyncio.Queue[dict] = asyncio.Queue()
         self.scope = scope
         self.stream_id = stream_id
         self.transmit = transmit
@@ -274,10 +274,10 @@ class WebTransportHandler:
             if not self.closed:
                 await self.send({"type": "webtransport.close"})
 
-    async def receive(self) -> Dict:
+    async def receive(self) -> dict:
         return await self.queue.get()
 
-    async def send(self, message: Dict) -> None:
+    async def send(self, message: dict) -> None:
         data = b""
         end_stream = False
 
@@ -325,7 +325,7 @@ Handler = Union[HttpRequestHandler, WebSocketHandler, WebTransportHandler]
 class HttpServerProtocol(QuicConnectionProtocol):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
-        self._handlers: Dict[int, Handler] = {}
+        self._handlers: dict[int, Handler] = {}
         self._http: Optional[HttpConnection] = None
 
     def http_event_received(self, event: H3Event) -> None:
@@ -361,9 +361,9 @@ class HttpServerProtocol(QuicConnectionProtocol):
             client = (client_addr[0], client_addr[1])
 
             handler: Handler
-            scope: Dict
+            scope: dict
             if method == "CONNECT" and protocol == "websocket":
-                subprotocols: List[str] = []
+                subprotocols: list[str] = []
                 for header, value in event.headers:
                     if header == b"sec-websocket-protocol":
                         subprotocols = [x.strip() for x in value.decode().split(",")]
@@ -387,9 +387,9 @@ class HttpServerProtocol(QuicConnectionProtocol):
                     transmit=self.transmit,
                 )
             elif method == "CONNECT" and protocol == "webtransport":
-                assert isinstance(
-                    self._http, H3Connection
-                ), "WebTransport is only supported over HTTP/3"
+                assert isinstance(self._http, H3Connection), (
+                    "WebTransport is only supported over HTTP/3"
+                )
                 scope = {
                     "client": client,
                     "headers": headers,
@@ -409,7 +409,7 @@ class HttpServerProtocol(QuicConnectionProtocol):
                     transmit=self.transmit,
                 )
             else:
-                extensions: Dict[str, Dict] = {}
+                extensions: dict[str, dict] = {}
                 if isinstance(self._http, H3Connection):
                     extensions["http.response.push"] = {}
                 scope = {
@@ -471,7 +471,7 @@ class SessionTicketStore:
     """
 
     def __init__(self) -> None:
-        self.tickets: Dict[bytes, SessionTicket] = {}
+        self.tickets: dict[bytes, SessionTicket] = {}
 
     def add(self, ticket: SessionTicket) -> None:
         self.tickets[ticket.ticket] = ticket
