@@ -9,7 +9,7 @@ from aioquic.quic.congestion.cubic import (
     CubicCongestionControl,
     better_cube_root,
 )
-from aioquic.quic.packet import PACKET_TYPE_INITIAL, PACKET_TYPE_ONE_RTT
+from aioquic.quic.packet import QuicPacketType
 from aioquic.quic.packet_builder import QuicSentPacket
 from aioquic.quic.rangeset import RangeSet
 from aioquic.quic.recovery import QuicPacketRecovery, QuicPacketSpace
@@ -58,7 +58,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=0.0,
         )
@@ -94,7 +94,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=False,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=123.45,
         )
@@ -130,7 +130,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=True,
             packet_number=0,
-            packet_type=PACKET_TYPE_INITIAL,
+            packet_type=QuicPacketType.INITIAL,
             sent_bytes=1280,
             sent_time=0.0,
         )
@@ -153,7 +153,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=0.0,
         )
@@ -246,7 +246,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=10.0,
         )
@@ -299,7 +299,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=0.0,
         )
@@ -337,7 +337,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=0.0,
         )
@@ -379,7 +379,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=0.0,
         )
@@ -418,7 +418,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=200.0,
         )
@@ -463,7 +463,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=200.0,
         )
@@ -474,7 +474,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=240.0,
         )
@@ -522,7 +522,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=200.0,
         )
@@ -564,7 +564,7 @@ class QuicPacketRecoveryCubicTest(TestCase):
             is_ack_eliciting=True,
             is_crypto_packet=False,
             packet_number=0,
-            packet_type=PACKET_TYPE_ONE_RTT,
+            packet_type=QuicPacketType.ONE_RTT,
             sent_bytes=1280,
             sent_time=0.0,
         )
