@@ -4,13 +4,25 @@ import functools
 import ipaddress
 import logging
 import os
+from typing import Callable, Coroutine, ParamSpec, TypeVar
 
 from cryptography import x509
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import ec, ed448, ed25519, rsa
 
+K = TypeVar(
+    "K",
+    ec.EllipticCurvePrivateKey,
+    ed448.Ed448PrivateKey,
+    ed25519.Ed25519PrivateKey,
+    rsa.RSAPrivateKey,
+)
+P = ParamSpec("P")
 
-def asynctest(coro):
+
+def asynctest(
+    coro: Callable[P, Coroutine[None, None, None]],
+) -> Callable[P, None]:
     @functools.wraps(coro)
     def wrap(*args, **kwargs):
         asyncio.run(coro(*args, **kwargs))
@@ -18,7 +30,7 @@ def asynctest(coro):
     return wrap
 
 
-def dns_name_or_ip_address(name):
+def dns_name_or_ip_address(name: str) -> x509.GeneralName:
     try:
         ip = ipaddress.ip_address(name)
     except ValueError:
@@ -27,7 +39,13 @@ def dns_name_or_ip_address(name):
         return x509.IPAddress(ip)
 
 
-def generate_certificate(*, alternative_names, common_name, hash_algorithm, key):
+def generate_certificate(
+    *,
+    alternative_names: list[str],
+    common_name: str,
+    hash_algorithm,
+    key: K,
+) -> tuple[x509.Certificate, K]:
     subject = issuer = x509.Name(
         [x509.NameAttribute(x509.NameOID.COMMON_NAME, common_name)]
     )
@@ -54,7 +72,9 @@ def generate_certificate(*, alternative_names, common_name, hash_algorithm, key)
     return cert, key
 
 
-def generate_ec_certificate(common_name, alternative_names=[], curve=ec.SECP256R1):
+def generate_ec_certificate(
+    common_name: str, alternative_names: list[str] = [], curve=ec.SECP256R1
+) -> tuple[x509.Certificate, ec.EllipticCurvePrivateKey]:
     key = ec.generate_private_key(curve=curve())
     return generate_certificate(
         alternative_names=alternative_names,
@@ -64,7 +84,9 @@ def generate_ec_certificate(common_name, alternative_names=[], curve=ec.SECP256R
     )
 
 
-def generate_ed25519_certificate(common_name, alternative_names=[]):
+def generate_ed25519_certificate(
+    common_name: str, alternative_names: list[str] = []
+) -> tuple[x509.Certificate, ed25519.Ed25519PrivateKey]:
     key = ed25519.Ed25519PrivateKey.generate()
     return generate_certificate(
         alternative_names=alternative_names,
@@ -74,7 +96,9 @@ def generate_ed25519_certificate(common_name, alternative_names=[]):
     )
 
 
-def generate_ed448_certificate(common_name, alternative_names=[]):
+def generate_ed448_certificate(
+    common_name: str, alternative_names: list[str] = []
+) -> tuple[x509.Certificate, ed448.Ed448PrivateKey]:
     key = ed448.Ed448PrivateKey.generate()
     return generate_certificate(
         alternative_names=alternative_names,
@@ -84,7 +108,9 @@ def generate_ed448_certificate(common_name, alternative_names=[]):
     )
 
 
-def generate_rsa_certificate(common_name, alternative_names=[]):
+def generate_rsa_certificate(
+    common_name: str, alternative_names: list[str] = []
+) -> tuple[x509.Certificate, rsa.RSAPrivateKey]:
     key = rsa.generate_private_key(public_exponent=65537, key_size=2048)
     return generate_certificate(
         alternative_names=alternative_names,
